@@ -24,7 +24,8 @@ from langchain_core.runnables import Runnable
 from langchain_core.tools import BaseTool
 from langchain_core.utils import from_env, secret_from_env
 from langchain_core.utils.function_calling import convert_to_openai_tool
-from langchain_openai.chat_models.base import BaseChatOpenAI
+from langchain_openai.chat_models._compat import _convert_from_v1_to_chat_completions
+from langchain_openai.chat_models.base import BaseChatOpenAI, _convert_message_to_dict
 import openai
 from pydantic import (
     BaseModel,
@@ -37,12 +38,19 @@ from pydantic import (
 )
 from typing_extensions import Self
 
+from ..types import ToolChoiceType
 
 _BM = TypeVar("_BM", bound=BaseModel)
 _DictOrPydanticClass = Union[dict[str, Any], type[_BM], type]
 _DictOrPydantic = Union[dict, _BM]
 
 
+class _ModelProviderConfigType(BaseModel):
+    supported_tool_choice: ToolChoiceType = Field(default=[])
+    keep_reasoning_content: bool = Field(default=False)
+    support_json_mode: bool = Field(default=False)
+
+
 class _BaseChatOpenAICompatible(BaseChatOpenAI):
     """
     Base template class for OpenAI-compatible chat model implementations.
@@ -77,7 +85,22 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
     model_config = ConfigDict(populate_by_name=True)
 
     _provider: str = PrivateAttr(default="openai-compatible")
-    _supported_tool_choice: list[str] = PrivateAttr(default=[])
+
+    provider_config: _ModelProviderConfigType = Field(
+        default_factory=lambda: _ModelProviderConfigType(),
+    )
+
+    @property
+    def _supported_tool_choice(self) -> ToolChoiceType:
+        return self.provider_config.supported_tool_choice
+
+    @property
+    def _keep_reasoning_content(self) -> bool:
+        return self.provider_config.keep_reasoning_content
+
+    @property
+    def _support_json_mode(self) -> bool:
+        return self.provider_config.support_json_mode
 
     @property
     def _llm_type(self) -> str:
@@ -96,6 +119,39 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
         ls_params["ls_provider"] = self._provider
         return ls_params
 
+    def _get_request_payload(
+        self,
+        input_: LanguageModelInput,
+        *,
+        stop: list[str] | None = None,
+        **kwargs: Any,
+    ) -> dict:
+        messages = self._convert_input(input_).to_messages()
+        if stop is not None:
+            kwargs["stop"] = stop
+
+        payload = {**self._default_params, **kwargs}
+
+        payload_messages = []
+
+        for m in messages:
+            if isinstance(m, AIMessage):
+                msg_dict = _convert_message_to_dict(
+                    _convert_from_v1_to_chat_completions(m)
+                )
+                if self._keep_reasoning_content and m.additional_kwargs.get(
+                    "reasoning_content"
+                ):
+                    msg_dict["reasoning_content"] = m.additional_kwargs.get(
+                        "reasoning_content"
+                    )
+                payload_messages.append(msg_dict)
+            else:
+                payload_messages.append(_convert_message_to_dict(m))
+
+        payload["messages"] = payload_messages
+        return payload
+
     @model_validator(mode="after")
     def validate_environment(self) -> Self:
         if not (self.api_key and self.api_key.get_secret_value()):
@@ -127,16 +183,6 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
             self.async_client = self.root_async_client.chat.completions
         return self
 
-    def _get_request_payload(
-        self,
-        input_: LanguageModelInput,
-        *,
-        stop: Optional[list[str]] = None,
-        **kwargs: Any,
-    ) -> dict:
-        payload = super()._get_request_payload(input_, stop=stop, **kwargs)
-        return payload
-
     def _create_chat_result(
         self,
         response: Union[dict, openai.BaseModel],
@@ -341,7 +387,7 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
                 tool_choice = "required"
             if isinstance(tool_choice, str):
                 if (
-                    tool_choice in ["auto", "none", "any", "required"]
+                    tool_choice in ["auto", "none", "required"]
                     and tool_choice in self._supported_tool_choice
                 ):
                     support_tool_choice = True
@@ -391,6 +437,9 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
         # Many providers do not support json_schema method, so fallback to function_calling
         if method == "json_schema":
             method = "function_calling"
+        if method == "json_mode" and not self._support_json_mode:
+            method = "function_calling"
+
         return super().with_structured_output(
             schema,
             method=method,
@@ -401,11 +450,7 @@ class _BaseChatOpenAICompatible(BaseChatOpenAI):
 
 
 def _create_openai_compatible_model(
-    provider: str,
-    base_url: str,
-    tool_choice: Optional[
-        list[Literal["auto", "none", "any", "required", "specific"]]
-    ] = None,
+    provider: str, base_url: str
 ) -> Type[_BaseChatOpenAICompatible]:
     """Factory function for creating provider-specific OpenAI-compatible model classes.
 
@@ -415,6 +460,8 @@ def _create_openai_compatible_model(
     Args:
         provider: Provider identifier (e.g., `vllm`)
         base_url: Default API base URL for the provider
+        tool_choice: List of tool choices for the model (e.g., ["auto", "none", "any", "required", "specific"])
+        keep_reasoning_content: Whether to keep reasoning content in the messages
 
     Returns:
         Configured model class ready for instantiation with provider-specific settings
@@ -442,8 +489,4 @@ def _create_openai_compatible_model(
             str,
             PrivateAttr(default=provider),
         ),
-        _supported_tool_choice=(
-            list[str],
-            PrivateAttr(default=tool_choice if tool_choice else []),
-        ),
     )
